.. tutorials:

=========
Tutorials
=========

Whilst RAFFLE is a random sturcture search package designed primarlily for interfaces, the tutorials will use bulk systems to demonstrate its functionality.

.. note::
    If you are looking for bulk random structure search, we recommend using packages such as `AIRSS <https://airss-docs.github.io>`_, which are specifically designed for this purpose.
    They take advantage of symmetries prevalent in bulk structures to reduce the search space and improve efficiency.
    RAFFLE does not account for these symmetries, due to their usual absence in interfaces.

.. toctree::
   :maxdepth: 2
   :caption: Tutorials:

   databases_tutorial
   diamond_tutorial
   graphite_tutorial
   aluminium_tutorial
   Si-Ge_tutorial
